##  Antipatterns
This section addresses antipatterns involving ineffective or counterproductive ways of modeling interfaces in SAP LeanIX.
  * Don't try to reflect the full technical complexity of the interface, but focus on the business question that you are trying to answer. SAP LeanIX diagrams are built with a business perspective in mind, focusing on the logical layer rather than on a technical-physical layer.
